@@ -1,7 +1,7 @@
 package XS::libdwarf;
 use 5.012;
 
-our $VERSION = "20200114.1";
+our $VERSION = "20200114.2";
 
 use XS::Loader;
 
@@ -25,10 +25,15 @@ In your Makefile.PL
 
 =head1 DESCRIPTION
 
-This module makes it possible to use DWARF library from XS modules.
+This module makes it possible to use L<DWARF library|https://sourceforge.net/projects/libdwarf/> 
+from XS modules.
 
 No perl interface.
 
+=head1 SEE ALSO
+
+L<DWARF library|https://sourceforge.net/projects/libdwarf/>й
+
 =head1 AUTHOR
 
 Ivan Baidakou <dmol@cpan.org>, Crazy Panda LTD
